@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-version = '0.1.5'
+version = '0.1.6'
 release = 'barium'
 
 import os
@@ -45,7 +45,7 @@ class Runner(object):
     Takes a base path as parameter (string), so that it can look for
     features and step definitions on there.
     """
-    def __init__(self, base_path, verbosity=0):
+    def __init__(self, base_path, scenarios=None, verbosity=0):
         """ lettuce.Runner will try to find a terrain.py file and
         import it from within `base_path`
         """
@@ -59,6 +59,7 @@ class Runner(object):
         sys.path.insert(0, base_path)
         self.loader = fs.FeatureLoader(base_path)
         self.verbosity = verbosity
+        self.scenarios = scenarios and map(int, scenarios.split(",")) or None
         try:
             self.terrain = _import("terrain")
         except Exception, e:
@@ -107,7 +108,7 @@ class Runner(object):
         try:
             for filename in features_files:
                 feature = Feature.from_file(filename)
-                results.append(feature.run())
+                results.append(feature.run(self.scenarios))
         except LettuceSyntaxError, e:
             sys.stderr.write(e.msg)
             failed = True
